summaryrefslogtreecommitdiffstats
path: root/kmobile/kmobile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/kmobile.cpp')
-rw-r--r--kmobile/kmobile.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/kmobile/kmobile.cpp b/kmobile/kmobile.cpp
index 8bd1da8a..d7628254 100644
--- a/kmobile/kmobile.cpp
+++ b/kmobile/kmobile.cpp
@@ -77,7 +77,7 @@ KMobile::KMobile()
connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
this, TQT_SLOT(changeStatusbar(const TQString&)));
// restore all configured tqdevices
restoreAll();
// setup the system tray
@@ -105,13 +105,13 @@ void KMobile::setupActions()
KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsPreferences()), actionCollection());
new KAction(i18n("&Add Device..."), "folder_new", 0,
- TQT_TQOBJECT(this), TQT_SLOT(addDevice()), actionCollection(), "tqdevice_add");
- new KAction( KGuiItem( i18n("&Remove Device"), "edittrash", i18n("Remove this tqdevice") ),
- "Delete", TQT_TQOBJECT(this), TQT_SLOT(removeDevice()), actionCollection(), "tqdevice_remove");
+ TQT_TQOBJECT(this), TQT_SLOT(addDevice()), actionCollection(), "device_add");
+ new KAction( KGuiItem( i18n("&Remove Device"), "edittrash", i18n("Remove this device") ),
+ "Delete", TQT_TQOBJECT(this), TQT_SLOT(removeDevice()), actionCollection(), "device_remove");
new KAction(i18n("Re&name Device..."), 0, Key_F2,
- TQT_TQOBJECT(this), TQT_SLOT(renameDevice()), actionCollection(), "tqdevice_rename");
+ TQT_TQOBJECT(this), TQT_SLOT(renameDevice()), actionCollection(), "device_rename");
new KAction(i18n("&Configure Device..."), "configure", 0,
- TQT_TQOBJECT(this), TQT_SLOT(configDevice()), actionCollection(), "tqdevice_configure");
+ TQT_TQOBJECT(this), TQT_SLOT(configDevice()), actionCollection(), "device_configure");
createGUI();
@@ -240,7 +240,7 @@ void KMobile::optionsPreferences()
void KMobile::renameDevice()
{
- // rename the current selected tqdevice
+ // rename the current selected device
TQIconViewItem *item = m_view->currentItem();
if (item)
item->rename();
@@ -258,7 +258,7 @@ void KMobile::addDevice()
dialog->setCaption( i18n("Add New Mobile or Portable Device") );
- dialog->helpText->setText( i18n("Please select the category to which your new tqdevice belongs:") );
+ dialog->helpText->setText( i18n("Please select the category to which your new device belongs:") );
dialog->addButton->setText( i18n("&Scan for New Devices...") );
dialog->addButton->setDisabled(true);
dialog->iconView->connect( dialog->iconView, TQT_SIGNAL(doubleClicked(TQIconViewItem*)),
@@ -273,7 +273,7 @@ void KMobile::addDevice()
for ( it = list.begin(); it != list.end(); ++it ) {
ptr = *it;
kdDebug() << TQString("LIBRARY: '%1', NAME: '%2', ICON: '%3', COMMENT: '%4'\n")
- .tqarg(ptr->library()).tqarg(ptr->name()).tqarg(ptr->icon()).tqarg(ptr->comment());
+ .arg(ptr->library()).arg(ptr->name()).arg(ptr->icon()).arg(ptr->comment());
TQString iconName = ptr->icon();
if (iconName.isEmpty())
@@ -297,13 +297,13 @@ void KMobile::addDevice()
ptr = list[index];
- // add the new tqdevice to the list
+ // add the new device to the list
if (!m_view->addNewDevice(m_config, ptr)) {
KMessageBox::error(this,
TQString("<qt>KMobile could not load the <b>%1</b> Device Driver.<p>"
"Please use the Skeleton- or Gnokii Device Driver during development.<p>"
"This driver will still be visible, but you won't be able to access it "
- "from Konqueror or any other application.</qt>").tqarg(ptr->name()),
+ "from Konqueror or any other application.</qt>").arg(ptr->name()),
kapp->name());
}
@@ -313,7 +313,7 @@ void KMobile::addDevice()
#if 0
/*
* show dialog to user, in which he may choose and select one of the already
* configured mobile tqdevices.
*/
KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
enum KMobileDevice::ClassType /*type*/, enum KMobileDevice::Capabilities /*caps*/ )
@@ -322,24 +322,24 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
m_parent = parent;
// do we already have some tqdevices configured ?
num = readDevicesList();
if (!num) {
int answ;
answ = KMessageBox::questionYesNo(parent,
- i18n( "<qt>You have no mobile tqdevices configured yet.<p>"
- "Do you want to add a tqdevice now ?</qt>" ),
+ i18n( "<qt>You have no mobile devices configured yet.<p>"
+ "Do you want to add a device now ?</qt>" ),
i18n( "KDE Mobile Device Access" ), KStdGuiItem::add(), i18n("Do Not Add") );
if (answ != KMessageBox::Yes)
return 0L;
- // add a new tqdevice
+ // add a new device
addDeviceDialog(parent);
}
num = readDevicesList();
if (!num)
return 0L;
// let the user select one of the configured tqdevices
KMobile_selectiondialog *dialog = new KMobile_selectiondialog(parent);
if (!dialog)
return 0L;
@@ -357,7 +357,7 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
continue;
// kdDebug() << TQString("LIBRARY: '%1', NAME: '%2', ICON: '%3', COMMENT: '%4' #%5\n")
- // .tqarg(ptr->library()).tqarg(ptr->name()).tqarg(ptr->icon()).tqarg(ptr->comment()).tqarg(i);
+ // .arg(ptr->library()).arg(ptr->name()).arg(ptr->icon()).arg(ptr->comment()).arg(i);
TQString iconName = ptr->icon();
if (iconName.isEmpty())
@@ -384,7 +384,7 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
void KMobile::removeDevice()
{
- // remove the current selected tqdevice
+ // remove the current selected device
TQIconViewItem *item = m_view->currentItem();
if (item)
m_view->removeDevice( item->text() );
@@ -392,7 +392,7 @@ void KMobile::removeDevice()
void KMobile::configDevice()
{
- // configure the current selected tqdevice
+ // configure the current selected device
TQIconViewItem *item = m_view->currentItem();
if (item)
m_view->configDevice( item->text() );
@@ -77,7 +77,7 @@ KMobile::KMobile()
connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
this, TQT_SLOT(changeStatusbar(const TQString&)));
- // restore all configured tqdevices
+ // restore all configured devices
restoreAll();
// setup the system tray
@@ -313,7 +313,7 @@ void KMobile::addDevice()
/*
* show dialog to user, in which he may choose and select one of the already
- * configured mobile tqdevices.
+ * configured mobile devices.
*/
KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
@@ -322,24 +322,24 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
m_parent = parent;
- // do we already have some tqdevices configured ?
+ // do we already have some devices configured ?
num = readDevicesList();
if (!num) {
@@ -322,24 +322,24 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
if (!num)
return 0L;
- // let the user select one of the configured tqdevices
+ // let the user select one of the configured devices
KMobile_selectiondialog *dialog = new KMobile_selectiondialog(parent);
if (!dialog)